Initializes a new instance of Client, to which all method calls are proxied.
Parameters:
includes options that are passed down to Bento::Analytics::Client#initialize
Options Hash (options):
If true, requests don’t hit the server and are stubbed to be successful.
28 29 30 31
# File 'lib/bento/analytics.rb', line 28 def initialize(options = {}) Transport.stub = options[:stub] if options.key?(:stub) @client = Bento::Analytics::Client.new options end